@@ -1,6 +1,6 @@
 
 /* Handle so called 'shell archives'.
-   Copyright (C) 1994-2014 Free Software Foundation, Inc.
+   Copyright (C) 1994-2015 Free Software Foundation, Inc.
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -50,6 +50,7 @@
 #endif
 
 #define EOL '\n'
+static inline unsigned char to_uchar (char ch) { return ch; }
 
 /** amount of data to read and write at once */
 size_t       rw_base_size = 0;
@@ -71,7 +72,7 @@ looks_like_c_code (char const * buf)
     "include", "define", "ifdef", "ifndef", "if",
     "pragma", "undef", "elif", "error", "line", NULL };
 
-  while (isspace ((int) *buf))  buf++;
+  while (isspace (to_uchar (*buf)))  buf++;
   switch (*(buf++))
     {
     case '#':
@@ -199,7 +200,8 @@ next_line_is_valid (char const * name, FILE * file)
       buf = fgets (rw_buffer, rw_base_size, file);
       if (buf == NULL)
         {
-          error (0, 0, _("Found no shell commands after cut line in %s"), name);
+          error (0, 0, _("Found no shell commands after cut line in %s"),
+                 name);
           return false;
         }
 
@@ -309,13 +311,13 @@ get_env_tmpdir(void)
 static FILE *
 load_file (char const ** tmp_fname, FILE * infp)
 {
-  static const char z_tmpfile[] = "unsh.XXXXXX";
+  static char const z_tmpfile[] = "unsh.XXXXXX";
   char * pz_fname;
   FILE * outfp;
 
   {
     size_t name_size;
-    char * pz_tmp = get_env_tmpdir();
+    char const * pz_tmp = get_env_tmpdir();
 
     name_size = strlen (pz_tmp) + sizeof (z_tmpfile) + 1;
     *tmp_fname = pz_fname = malloc (name_size);
